DynamicRoute

Struct DynamicRoute 

pub struct DynamicRoute { /* private fields */ }
A set of dynamic API routes.

Dynamic routes allow for processes to dynamically register/unregister themselves from running API endpoints, adapting to changes in the process state and without requiring all routes to be known and declared upfront.

Implementations

Source

impl DynamicRoute

pub fn http<T: APIHandler>(endpoint_type: EndpointType, handler: T) -> Self

Creates a dynamic HTTP route from the given API handler.

pub fn grpc(endpoint_type: EndpointType, routes: Routes) -> Self

Creates a dynamic gRPC route from the given Tonic routes.

pub fn endpoint_type(&self) -> EndpointType

Returns the type of endpoint these routes target.

pub fn endpoint_protocol(&self) -> EndpointProtocol

Returns the protocol of endpoint these routes target.

pub fn into_router(self) -> Router<()>

Consumes this route and returns the underlying router.