pub struct DynamicRoute { /* private fields */ }Expand description
A set of dynamic API routes.
Dynamic routes allow for processes to dynamically register/unregister themselves from running API endpoints, adapting to changes in the process state and without requiring all routes to be known and declared upfront.
Implementations
Sourceimpl DynamicRoute
impl DynamicRoute
Sourcepub fn http<T: APIHandler>(endpoint_type: EndpointType, handler: T) -> Self
pub fn http<T: APIHandler>(endpoint_type: EndpointType, handler: T) -> Self
Creates a dynamic HTTP route from the given API handler.
Sourcepub fn grpc(endpoint_type: EndpointType, routes: Routes) -> Self
pub fn grpc(endpoint_type: EndpointType, routes: Routes) -> Self
Creates a dynamic gRPC route from the given Tonic routes.
Sourcepub fn endpoint_type(&self) -> EndpointType
pub fn endpoint_type(&self) -> EndpointType
Returns the type of endpoint these routes target.
Sourcepub fn endpoint_protocol(&self) -> EndpointProtocol
pub fn endpoint_protocol(&self) -> EndpointProtocol
Returns the protocol of endpoint these routes target.
Sourcepub fn into_router(self) -> Router<()>
pub fn into_router(self) -> Router<()>
Consumes this route and returns the underlying router.